%global momorel 2

Summary: Lightweight library for embedding a webserver in applications
Name: libmicrohttpd
Version: 0.9.59
Release: %{momorel}m%{?dist}
Group: Development/Libraries
License: LGPLv2+
BuildRoot: %(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)
URL: http://www.gnu.org/software/libmicrohttpd/
Source0: http://ftp.gnu.org/gnu/libmicrohttpd/%{name}-%{version}.tar.gz
NoSource: 0

BuildRequires:  autoconf, automake, libtool
BuildRequires:	libcurl-devel
BuildRequires:  gnutls-devel >= 3.6.2
BuildRequires:  libgcrypt-devel >= 1.7.5
BuildRequires:  graphviz
BuildRequires:  doxygen

Requires(post): info
Requires(preun): info

%description
GNU libmicrohttpd is a small C library that is supposed to make it
easy to run an HTTP server as part of another application.
Key features that distinguish libmicrohttpd from other projects are:

* C library: fast and small
* API is simple, expressive and fully reentrant
* Implementation is http 1.1 compliant
* HTTP server can listen on multiple ports
* Support for IPv6
* Support for incremental processing of POST data
* Creates binary of only 25k (for now)
* Three different threading models

%package devel
Summary:        Development files for libmicrohttpd
Group:          Development/Libraries
Requires:       %{name} = %{version}-%{release}

%description devel
Development files for libmicrohttpd

%package doc
Summary:        Documentation for libmicrohttpd
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description doc
Doxygen documentation for libmicrohttpd and some example source code

%prep
%setup -q

%build
# Required because patches modify .am files
# autoreconf --force
%configure --disable-static --with-gnutls
make %{?_smp_mflags}

# Disabled for now due to problems reported at
# https://gnunet.org/bugs/view.php?id=1619
#check
#make check %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}

rm -f %{buildroot}%{_libdir}/libmicrohttpd.la
rm -f %{buildroot}%{_infodir}/dir

# Install some examples in /usr/share/doc/libmicrohttpd-${version}/examples
mkdir examples
install -m 644 src/examples/*.c examples

find %{buildroot} -name "*.la" -exec rm -f {} \;

%clean
rm -rf %{buildroot}

%post doc
/sbin/install-info %{_infodir}/libmicrohttpd.info.bz2 %{_infodir}/dir || :
/sbin/install-info %{_infodir}/libmicrohttpd-tutorial.info.bz2 %{_infodir}/dir || :

%preun doc
if [ $1 = 0 ] ; then
/sbin/install-info --delete %{_infodir}/libmicrohttpd.info.bz2 %{_infodir}/dir || :
/sbin/install-info --delete %{_infodir}/libmicrohttpd-tutorial.info.bz2 %{_infodir}/dir || :
fi

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYING
%{_libdir}/libmicrohttpd.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/microhttpd.h
%{_libdir}/libmicrohttpd.so
%{_libdir}/pkgconfig/libmicrohttpd.pc

%files doc
%defattr(-,root,root,-)
%{_mandir}/man3/libmicrohttpd.3.*
%{_infodir}/libmicrohttpd.info.*
%{_infodir}/libmicrohttpd-tutorial.info.*
%{_infodir}/libmicrohttpd_performance_data.png.*
%doc AUTHORS README ChangeLog
%doc examples

%changelog
* Tue Jun 26 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.59-2m)
- rebuild against gnutls-3.6.2

* Mon Feb 26 2018 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.59-1m)
- update 0.9.59

* Thu Dec 28 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.58-1m)
- update 0.9.58

* Wed Jun 21 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.55-1m)
- update 0.9.55

* Wed Feb 01 2017 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.52-1m)
- update 0.9.52

* Wed Jun 15 2016 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.50-1m)
- update 0.9.50

* Sat Oct 31 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.44-1m)
- update 0.9.44

* Wed Sep 30 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.43-1m)
- update 0.9.43

* Thu Jun 11 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.42-1m)
- update 0.9.42

* Sun May 10 2015 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.41-1m)
- update 0.9.41

* Tue Oct 14 2014 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.38-1m)
- update 0.9.38

* Sat Jul 05 2014 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.37-1m)
- update 0.9.37

* Fri Apr 11 2014 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (0.9.34-2m)
- rebuild against graphviz-2.36.0-1m

* Fri Feb 28 2014 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.34-1m)
- update 0.9.34

* Sat Oct 05 2013 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.30-1m)
- update 0.9.30

* Sat Jun  1 2013 NaRITA Koichi <pulsar@momonga-linux.org>
- (0.9.27-2m)
- rebuild against gnutls-3.2.0

* Wed May  8 2013 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.9.27-1m)
- update 0.9.27

* Sun Nov 11 2012 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.9.23-1m)
- update 0.9.23

* Wed Oct 24 2012 Yohsuke Ooi <meke@momonga-linux.org> 
- (0.9.22-1m)
- Initial Commit Momonga Linux

* Thu Sep 27 2012 Tim Niemueller <tim@niemueller.de> - 0.9.22-1
- Update to latest uptsream release 0.9.22

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Feb 27 2011 Tim Niemueller <tim@niemueller.de> - 0.9.7-1
- Update to new upstream release 0.9.7
- Remove upstreamed patches

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 26 2011 Tim Niemueller <tim@niemueller.de> - 0.9.6-1
- Update to new upstream release 0.9.6

* Mon Jan 24 2011 Tim Niemueller <tim@niemueller.de> - 0.9.5-1
- Update to new upstream release 0.9.5

* Tue Nov 16 2010 Tim Niemueller <tim@niemueller.de> - 0.9.2-3
- Add missing BR gnutls-devel and libgcrypt-devel
- Added patch to fix test apps (NSS instead of GnuTLS/OpenSSL curl,
  implicit DSO linking)
- Disable test cases for now due to false errors, reported upstream

* Tue Nov 16 2010 Tim Niemueller <tim@niemueller.de> - 0.9.2-2
- Re-enable HTTPS, configure flags had unexpected result

* Sun Nov  7 2010 Tim Niemueller <tim@niemueller.de> - 0.9.2-1
- Update to 0.9.2

* Sun Jun  4 2010 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.4.6-1
- Update to 0.4.6

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 21 2009 Erik van Pienbroek <epienbro@fedoraproject.org> - 0.4.2-1
- Update to version 0.4.2
- Drop upstreamed patch

* Fri Feb 27 2009 Erik van Pienbroek <info@nntpgrab.nl> - 0.4.0a-1
- Update to version 0.4.0a
- Drop upstreamed patch
- Added a new patch to fix a 64bit issue
- The -devel package now contains a pkgconfig file
- The configure script is now run with '--enable-messages --enable-https'
- Made the -doc subpackage noarch (F11+)

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Feb 14 2009 Erik van Pienbroek <info@nntpgrab.nl> - 0.4.0-1
- Update to version 0.4.0
- This version introduces a API bump (which is required for
  supporting large files on 32bit environments)
- The license issues we had with version 0.3.1 of this package (as
  discussed in #457924) are resolved in this version. The license
  of this package is now changed to LGPLv2+
- Added a patch to fix two testcases on 64bit environments (upstream bug #1454)

* Sat Sep 6 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-3
- Changed license to GPLv3+ and added some comments
  regarding the license issues with this package

* Sun Aug 10 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-2
- Changed license to LGPLv2+
- Moved the COPYING file to the main package

* Tue Aug 5 2008 Erik van Pienbroek <info@nntpgrab.nl> - 0.3.1-1
- Initial release

